#!/bin/bash

MATERIALS_DIR=".lab-containers-part-2-helpers"
PLAYGROUND_DIR="lab-containers-part-2"

# Clone the repository with helper files
git clone --depth=1 --recurse-submodules --shallow-submodules https://github.com/rosedu/workshop-docker.git "$MATERIALS_DIR"

# Function to build a Docker image from a specific path
build_docker_image() {
    local image_name=$1
    local dockerfile_path=$2

    if [[ -z "$image_name" || -z "$dockerfile_path" ]]; then
        echo "Usage: build_docker_image <image_name> <dockerfile_path>"
        return 1
    fi

    if [[ ! -d "$dockerfile_path" ]]; then
        echo "Error: Directory $dockerfile_path does not exist."
        return 1
    fi

    echo "Building Docker image '$image_name' from $dockerfile_path/Dockerfile..."

    cd "$dockerfile_path" || return 1
    docker build -t "$image_name" -f Dockerfile .
    cd - > /dev/null
}

build_docker_image "perpetual-writer" "$MATERIALS_DIR/volume-demo"
build_docker_image "python-container" "$MATERIALS_DIR/python-container"

# Create a folder named playground which is student facing
mkdir -p $PLAYGROUND_DIR
cp -r $MATERIALS_DIR/nginx-website $PLAYGROUND_DIR
cp -r $MATERIALS_DIR/nginx-confs $PLAYGROUND_DIR
cp -r $MATERIALS_DIR/python-container $PLAYGROUND_DIR

# Remove artefacts
rm -rf $MATERIALS_DIR
